## Version 0.5.0 (2026/02/19)


### Pull Requests Merged

#### Features added

* [PR 13](https://github.com/pytroll/pytroll-monitor/pull/13) - Porting to pyproject.toml

In this release 1 pull request was closed.


## Version 0.4.0 (2026/02/18)



## Version 0.3.0 (2023/04/26)


### Pull Requests Merged

#### Bugs fixed

* [PR 9](https://github.com/pytroll/pytroll-monitor/pull/9) - Fix op5, needed post in the end
* [PR 8](https://github.com/pytroll/pytroll-monitor/pull/8) - Fix op5 to use GET, not POST

#### Features added

* [PR 10](https://github.com/pytroll/pytroll-monitor/pull/10) - Remove six

In this release 3 pull requests were closed.


## Version v0.2.0 (2022/07/18)

### Issues Closed

* [Issue 3](https://github.com/pytroll/pytroll-monitor/issues/3) - Needs GitHub CI

In this release 1 issue was closed.

### Pull Requests Merged

#### Bugs fixed

* [PR 5](https://github.com/pytroll/pytroll-monitor/pull/5) - Fix name of CheckMKLogger in unit test
* [PR 4](https://github.com/pytroll/pytroll-monitor/pull/4) - Prepare for Github actions CI workflow

#### Features added

* [PR 6](https://github.com/pytroll/pytroll-monitor/pull/6) - Add tests for op5 handler and use requests
* [PR 4](https://github.com/pytroll/pytroll-monitor/pull/4) - Prepare for Github actions CI workflow
* [PR 2](https://github.com/pytroll/pytroll-monitor/pull/2) - Add a checkmk monitor logger handler

In this release 5 pull requests were closed.
